@@ -13,7 +13,7 @@ use vars '@EXPORT_OK';
 
 @EXPORT_OK = (qw(is_xml_ordered));
 
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 
 sub new
 {
@@ -212,10 +212,13 @@ sub _compare_loop
 
                     foreach my $attr (@list)
                     {
-                        $attr->{value} = $elem->getAttributeNs(
-                            $attr->{localName},
-                            $attr->{ns},
-                        ) // '';
+                        $attr->{value} = ((length($attr->{ns})
+                            ?  $elem->getAttributeNs(
+                                $attr->{localName},
+                                $attr->{ns},
+                            )
+                            : $elem->getAttribute($attr->{localName})
+                        ) // '');
                     }
 
                     return
@@ -374,6 +377,13 @@ sub _get_diag_message
             " ; " .
             "Expected Attribute localName: <<$status_struct->{expected}>> at  " .$self->_expected->lineNumber();
     }
+    elsif ($status_struct->{param} eq "attr_value")
+    {
+        return
+            "Got Attribute value: <<$status_struct->{got}>> at " . $self->_got->lineNumber() .
+            " ; " .
+            "Expected Attribute value: <<$status_struct->{expected}>> at  " .$self->_expected->lineNumber();
+    }
     else
     {
         die "Unknown param: $status_struct->{param}";
